@@ -469,11 +469,11 @@ make.RapData <- function(pus, species, spaces = NULL, amount.target = 0.2,
   # set polygons
   geoPolygons <- pus
   if (!raster::compareCRS(geoPolygons@proj4string,
-                          sp::CRS("+init=epsg:4326")) &&
+                          sp::CRS("EPSG:4326")) &&
       !identical(geoPolygons@proj4string, sp::CRS())) {
     if (verbose)
       message("Projecting polygons to WGS1984 for rendering.")
-    geoPolygons <- sp::spTransform(geoPolygons, sp::CRS("+init=epsg:4326"))
+    geoPolygons <- sp::spTransform(geoPolygons, sp::CRS("EPSG:4326"))
   }
   geoPolygons <- rcpp_Polygons2PolySet(geoPolygons@polygons)
   ## set pu
@@ -498,7 +498,7 @@ make.RapData <- function(pus, species, spaces = NULL, amount.target = 0.2,
     pu$area <- rgeos::gArea(pus, byid = TRUE)
     warning(paste0("argument to pus does not have a \"area\" column, ",
                    "calcuating planning unit areas using polygons"))
-    if (raster::compareCRS(pus@proj4string, sp::CRS("+init=epsg:4326")))
+    if (raster::compareCRS(pus@proj4string, sp::CRS("EPSG:4326")))
       warning(paste0("Planning unit areas are being calculated in a ",
                      "geographic coordinate system"))
   }
@@ -645,7 +645,7 @@ make.RapData <- function(pus, species, spaces = NULL, amount.target = 0.2,
     )
   })
   ## set boundary
-  if (raster::compareCRS(pus@proj4string, sp::CRS("+init=epsg:4326")))
+  if (raster::compareCRS(pus@proj4string, sp::CRS("EPSG:4326")))
     warning(paste0("creating boundary length data from pus in WGS1984; ",
                    "consider supplying an object in a projected CRS."))
   if (verbose)
@@ -669,15 +669,20 @@ make.RapData <- function(pus, species, spaces = NULL, amount.target = 0.2,
 #' @rdname basemap
 basemap.RapData <- function(x, basemap = "hybrid", grayscale = FALSE,
                             force.reset = FALSE) {
+  assertthat::assert_that(
+    requireNamespace("RgoogleMaps", quietly = TRUE),
+    msg = "please install the \"RgoogleMaps\" package"
+  )
   assertthat::assert_that(assertthat::is.string(basemap),
                           assertthat::is.flag(grayscale),
                           assertthat::is.flag(force.reset))
   callchar <- hashCall(match.call(), 1)
   match.arg(basemap, c("roadmap", "mobile", "satellite", "terrain", "hybrid",
                        "mapmaker-roadmap", "mapmaker-hybrid"))
-  if (is.null(x@polygons))
-  stop(paste0("Rap object is not associated with spatially explicit data ",
-              "for the planning units."))
+  if (is.null(x@polygons)) {
+    stop(paste0("Rap object is not associated with spatially explicit data ",
+                "for the planning units."))
+  }
   # fetch data from google or cache
   if (force.reset || !is.cached(x, callchar)) {
     cache(x, callchar,
@@ -972,7 +977,7 @@ spp.plot.RapData <- function(x, species, prob.color.palette = "YlGnBu",
                              pu.color.palette = c("#4D4D4D", "#00FF00",
                                                   "#FFFF00", "#FF0000"),
                              basemap = "none",
-                             alpha = ifelse(basemap == "none", 1, 0.7),
+                             alpha = ifelse(identical(basemap, "none"), 1, 0.7),
                              grayscale = FALSE, main = NULL,
                              force.reset = FALSE,
   ...
@@ -1135,8 +1140,9 @@ amount.target.RapData <- function(x, species = NULL) {
   } else {
     if (is.character(species))
       species <- match(species, x@species$name)
-    if (!all(species %in% seq_len(nrow(x@species))))
+    if (!all(species %in% seq_len(nrow(x@species)))) {
       stop("species not present in argument to x")
+    }
     pos <- which(x@targets$target == 0 & x@targets$species %in% species)
     x@targets$proportion[pos] <- value
   }
@@ -1180,7 +1186,7 @@ space.target.RapData <- function(x, species = NULL, space = NULL) {
 #' @rdname space.target
 #'
 #' @export
-`space.target<-.RapData` <- function(x, species=NULL, space=NULL, value) {
+`space.target<-.RapData` <- function(x, species = NULL, space = NULL, value) {
   assertthat::assert_that(is.null(species) || is.character(species) ||
                           is.numeric(species),
                           is.null(space) || is.numeric(space),
