@@ -1,10 +1,8 @@
 context("11-RapUnsolved")
-source("functions.R")
 
 test_that("Gurobi solver (unreliable)", {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -18,9 +16,14 @@ test_that("Gurobi solver (unreliable)", {
   model$A <- Matrix::sparseMatrix(i = model$Ar[[1]] + 1, j = model$Ar[[2]] + 1,
                                   x = model$Ar[[3]])
   # solve the model
-  result <- gurobi::gurobi(model, append(as.list(
-    GurobiOpts(MIPGap = 0, Presolve = 1L)),
-    list("LogFile" = tempfile(fileext = ".log"))))
+  result <-
+    withr::with_locale(
+      c(LC_CTYPE = "C"),
+      gurobi::gurobi(model, append(
+        as.list(GurobiOpts(MIPGap = 0, Presolve = 1L)),
+        list("LogFile" = tempfile(fileext = ".log"), "LogToConsole" = 0L))
+      )
+    )
   if (file.exists("gurobi.log")) unlink("gurobi.log")
   # check solution variables
   expect_true(all(result$x[grep("pu_",  dump_object(model$cache$variables,
@@ -31,7 +34,7 @@ test_that("Gurobi solver (unreliable)", {
 
 test_that("Gurobi solver (reliable)", {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE)) skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -43,9 +46,14 @@ test_that("Gurobi solver (reliable)", {
   model$A <- Matrix::sparseMatrix(i = model$Ar[[1]] + 1, j = model$Ar[[2]] + 1,
                                   x = model$Ar[[3]])
   # solve the model
-  result <- gurobi::gurobi(model, append(as.list(
-    GurobiOpts(MIPGap = 0, Presolve = 1L)),
-    list("LogFile" = tempfile(fileext = ".log"))))
+  result <- withr::with_locale(
+    c(LC_CTYPE = "C"),
+    gurobi::gurobi(model, append(
+      as.list(GurobiOpts(MIPGap = 0, Presolve = 1L)),
+      list("LogFile" = tempfile(fileext = ".log"), "LogToConsole" = 0L)
+      )
+    )
+  )
   if (file.exists("gurobi.log")) unlink("gurobi.log")
   # checks
   expect_true(all(result$x[grep("pu_", dump_object(model$cache$variables,
@@ -87,8 +95,7 @@ test_that("maximum.targets (reliable)", {
 test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=1 - ",
                  "MultipleSolutionsMethod=benders.cuts)"), {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -97,7 +104,7 @@ test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=1 - ",
   sim_ru@data@targets[[3]] <- c(0.5, 0.5, 0.5, 0.1, 0.1, 0.1)
   # solve it
   sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L),
-                         verbose = TRUE)
+                         verbose = FALSE)
   # run checks
   expect_equal(nrow(summary(sim_rs)), 1L)
   runUnreliableChecks(sim_rs)
@@ -106,8 +113,7 @@ test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=1 - ",
 test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=1 - ",
                  "MultipleSolutionsMethod=benders.cuts)"), {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -118,7 +124,7 @@ test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=1 - ",
   # solve it
   expect_warning({
     sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L),
-                           verbose = TRUE)
+                           verbose = FALSE)
   })
   # run checks
   expect_equal(nrow(summary(sim_rs)), 1L)
@@ -128,8 +134,7 @@ test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=1 - ",
 test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=1 - ",
                  "MultipleSolutionsMethod=solution.pool.2)"), {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -141,7 +146,7 @@ test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=1 - ",
                          GurobiOpts(MIPGap = 0, Presolve = 2L,
                                     MultipleSolutionsMethod =
                                       "solution.pool.2"),
-                         verbose = TRUE)
+                         verbose = FALSE)
   # run checks
   expect_equal(nrow(summary(sim_rs)), 1L)
   runUnreliableChecks(sim_rs)
@@ -150,8 +155,7 @@ test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=1 - ",
 test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=1 - ",
                  "MultipleSolutionsMethod=solution.pool.1)"), {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -165,7 +169,7 @@ test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=1 - ",
                            GurobiOpts(MIPGap = 0, Presolve = 2L,
                                       MultipleSolutionsMethod =
                                         "solution.pool.1"),
-                           verbose = TRUE)
+                           verbose = FALSE)
   })
   # run checks
   expect_equal(nrow(summary(sim_rs)), 1L)
@@ -175,8 +179,7 @@ test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=1 - ",
 test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=1 -",
                  "sparse occupancy)"), {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -211,17 +214,18 @@ test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=1 -",
       )
   })
   # solve it
-  sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L))
+  sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L),
+                         verbose = FALSE)
   # run checks
   expect_equal(nrow(summary(sim_rs)), 1L)
   runUnreliableChecks(sim_rs)
 })
 
+
 test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=1 - sparse ",
                  "occupancy)"), {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -256,7 +260,7 @@ test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=1 - sparse ",
   # solve it
   expect_warning({
     sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0.5, Presolve = 2L),
-                           verbose = TRUE)
+                           verbose = FALSE)
   })
   # run checks
   expect_equal(nrow(summary(sim_rs)), 1L)
@@ -266,8 +270,7 @@ test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=1 - sparse ",
 test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=3 - ",
                  "MultipleSolutionsMethod=benders.cuts)"), {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -278,7 +281,8 @@ test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=3 - ",
   # solve it
   sim_rs <- raptr::solve(sim_ru,
                          GurobiOpts(MIPGap = 0, Presolve = 2L,
-                                    NumberSolutions = 3L))
+                                    NumberSolutions = 3L),
+                         verbose = FALSE)
   # run checks
   expect_equal(nrow(summary(sim_rs)), 3L)
   runUnreliableChecks(sim_rs)
@@ -287,8 +291,7 @@ test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=3 - ",
 test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=3 - ",
                 "MultipleSolutionsMethod=benders.cuts)"), {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -300,7 +303,8 @@ test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=3 - ",
   expect_warning({
     sim_rs <- raptr::solve(sim_ru,
                            GurobiOpts(MIPGap = 0, Presolve = 2L,
-                                      NumberSolutions = 3L))
+                                      NumberSolutions = 3L),
+                           verbose = FALSE)
   })
   # check number of selections is 1
   expect_equal(nrow(summary(sim_rs)), 3L)
@@ -310,7 +314,7 @@ test_that(paste0("solve.RapUnsolved (reliable - NumberSolutions=3 - ",
 test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=2 - ",
                  "MultipleSolutionsMethod=solution.pool.2)"), {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE)) skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -323,7 +327,8 @@ test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=2 - ",
                          GurobiOpts(MIPGap = 0, Presolve = 2L,
                                     NumberSolutions = 2L,
                                     MultipleSolutionsMethod =
-                                      "solution.pool.2"))
+                                      "solution.pool.2"),
+                         verbose = FALSE)
   # run checks
   expect_equal(nrow(summary(sim_rs)), 2L)
   runUnreliableChecks(sim_rs)
@@ -331,8 +336,7 @@ test_that(paste0("solve.RapUnsolved (unreliable - NumberSolutions=2 - ",
 
 test_that("solve.RapUnsolved (unreliable - STATUS test)", {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -345,7 +349,8 @@ test_that("solve.RapUnsolved (unreliable - STATUS test)", {
   sim_ru@data@pu$status[2] <- 2L
   sim_ru@data@pu$status[3] <- 3L
   # solve it
-  sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L))
+  sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L),
+                         verbose = FALSE)
   # run checks
   expect_equal(nrow(summary(sim_rs)), 1L)
   expect_identical(selections(sim_rs)[2], 1L)
@@ -355,8 +360,7 @@ test_that("solve.RapUnsolved (unreliable - STATUS test)", {
 
 test_that("solve.RapUnsolved (reliable - STATUS test)", {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -370,7 +374,8 @@ test_that("solve.RapUnsolved (reliable - STATUS test)", {
   sim_ru@data@pu$status[3] <- 3L
   # solve it
   expect_warning({
-    sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L))
+    sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L),
+                           verbose = FALSE)
   })
   # run checks
   expect_equal(nrow(summary(sim_rs)), 1L)
@@ -381,8 +386,7 @@ test_that("solve.RapUnsolved (reliable - STATUS test)", {
 
 test_that("solve.RapUnsolved (unreliable - BLM test)", {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -391,15 +395,15 @@ test_that("solve.RapUnsolved (unreliable - BLM test)", {
   sim_ru <- dp.subset(sim_ru, species = 1:3, space = 1, points = 1:30)
   sim_ru@data@targets[[3]] <- c(0.5, 0.5, 0.5, 0.1, 0.1, 0.1)
   # solve it
-  sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L))
+  sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L),
+                         verbose = FALSE)
   # run checks
   runUnreliableChecks(sim_rs)
 })
 
 test_that("solve.RapUnsolved (reliable - BLM test)", {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -409,7 +413,8 @@ test_that("solve.RapUnsolved (reliable - BLM test)", {
   sim_ru@data@targets[[3]] <- c(0.5, 0.5, 0.5, -10000, -10000, -10000)
   # solve it
   expect_warning({
-    sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L))
+    sim_rs <- raptr::solve(sim_ru, GurobiOpts(MIPGap = 0, Presolve = 2L),
+                           verbose = FALSE)
   })
   # run checks
   runReliableChecks(sim_rs)
@@ -431,15 +436,14 @@ test_that("solve.RapUnsolved (manual solution, omitting all attribute space plan
     sim_ru@data@attribute.spaces[[1]]@spaces[[1]]@planning.unit.points@ids[-1]
   sim_ru@data@targets[[3]] <- c(0.5, 0.1)
   # solve it
-  sim_rs <- suppressWarnings(raptr::solve(sim_ru, c(1)))
+  sim_rs <- suppressWarnings(raptr::solve(sim_ru, c(1), verbose = FALSE))
   expect_is(sim_rs, "RapSolved")
   expect_equal(space.held(sim_rs, 1)[[1]], -Inf)
 })
 
 test_that("solve.RapUnsolved (single demand point)", {
   # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
+  skip_if_not_installed("gurobi")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -455,7 +459,9 @@ test_that("solve.RapUnsolved (single demand point)", {
   sim_ru@data@targets[[3]] <- c(0.1, 0)
   sim_ru@data@pu$cost <- c(5, 1, seq_len(3))
   # solve it
-  sim_rs <- suppressWarnings(raptr::solve(sim_ru, GurobiOpts(MIPGap = 0)))
+  sim_rs <- suppressWarnings(
+    raptr::solve(sim_ru, GurobiOpts(MIPGap = 0), verbose = FALSE)
+  )
   expect_is(sim_rs, "RapSolved")
   expect_true(is.na(space.held(sim_rs, 1)[[1]]))
   expect_equal(selections(sim_rs), c(0, 1, 0, 0, 0))
@@ -516,9 +522,6 @@ test_that("space.target<-.RapUnsolved", {
 })
 
 test_that("space.plot.RapUnsolved (sparse)", {
-  # skip if gurobi not installed
-  if (!is.GurobiInstalled(FALSE))
-    skip("Gurobi not installed on system")
   # load RapUnsolved object
   set.seed(500)
   data(sim_ru)
@@ -549,7 +552,7 @@ test_that("space.plot.RapUnsolved (sparse)", {
         }),
         name = sim_ru@data@attribute.spaces[[i]]@name)
   })
-  # try plotting spase data
+  # try plotting space data
   space.plot(sim_rs, 1, 1, main = "spp1")
   space.plot(sim_rs, 2, 1, main = "spp2")
   space.plot(sim_rs, 3, 1, main = "spp3")
